@@ -12,8 +12,6 @@
 #include "comic.h"
 #include "checknewstrips.h"
 #include "comic_debug.h"
-#include "comicarchivedialog.h"
-#include "comicarchivejob.h"
 #include "comicsaver.h"
 #include "stripselector.h"
 
@@ -28,9 +26,12 @@
 #include <QWindow>
 
 #include <KActionCollection>
+#include <KApplicationTrader>
 #include <KConfigDialog>
 #include <KIO/OpenUrlJob>
+#include <KLocalizedString>
 #include <KNotification>
+#include <KService>
 #include <KStandardShortcut>
 #include <kuiserverjobtracker.h>
 
@@ -101,6 +102,18 @@ void ComicApplet::init()
     mActions.append(mActionGoJump);
     connect(mActionGoJump, &QAction::triggered, this, &ComicApplet::slotGoJump);
 
+    mActionWebsite = new QAction(i18nc("@action", "Visit the Website"), this);
+    KService::Ptr browser = KApplicationTrader::preferredService(QStringLiteral("x-scheme-handler/https"));
+
+    if (browser) {
+        mActionWebsite->setText(i18nc("@action:inmenu %1 is the name of a web browser", "View in %1", browser->name()));
+        mActionWebsite->setIcon(QIcon::fromTheme(browser->icon()));
+    }
+
+    mActionWebsite->setEnabled(false);
+    mActions.append(mActionWebsite);
+    connect(mActionWebsite, &QAction::triggered, this, &ComicApplet::slotWebsite);
+
     mActionShop = new QAction(i18nc("@action", "Visit the Shop &Website"), this);
     mActionShop->setEnabled(false);
     mActions.append(mActionShop);
@@ -110,10 +123,6 @@ void ComicApplet::init()
     mActions.append(mActionSaveComicAs);
     connect(mActionSaveComicAs, &QAction::triggered, this, &ComicApplet::slotSaveComicAs);
 
-    mActionCreateComicBook = new QAction(QIcon::fromTheme(QStringLiteral("application-epub+zip")), i18nc("@action", "&Create Comic Book Archive…"), this);
-    mActions.append(mActionCreateComicBook);
-    connect(mActionCreateComicBook, &QAction::triggered, this, &ComicApplet::createComicBook);
-
     mActionScaleContent = new QAction(QIcon::fromTheme(QStringLiteral("zoom-original")), //
                                       i18nc("@option:check Context menu of comic image", "&Actual Size"),
                                       this);
@@ -186,8 +195,6 @@ void ComicApplet::dataUpdated(const ComicMetaData &data)
 
     mCurrent.setData(data);
 
-    setAssociatedApplicationUrls(QList<QUrl>() << mCurrent.websiteUrl());
-
     // looking at the last index, thus not mark it as new
     KConfigGroup cg = config();
     if (!mCurrent.hasNext() && mCheckNewComicStripsInterval) {
@@ -411,55 +418,18 @@ void ComicApplet::slotStorePosition()
     mCurrent.storePosition(mActionStorePosition->isChecked());
 }
 
+void ComicApplet::slotWebsite()
+{
+    auto *job = new KIO::OpenUrlJob(mCurrent.websiteUrl());
+    job->start();
+}
+
 void ComicApplet::slotShop()
 {
     auto *job = new KIO::OpenUrlJob(mCurrent.shopUrl());
     job->start();
 }
 
-void ComicApplet::createComicBook()
-{
-    ComicArchiveDialog *dialog = new ComicArchiveDialog(mCurrent.id(), //
-                                                        mCurrent.title(),
-                                                        mCurrent.type(),
-                                                        mCurrent.current(),
-                                                        mCurrent.first(),
-                                                        mSavingDir->getDir());
-    dialog->setAttribute(Qt::WA_DeleteOnClose); // to have destroyed emitted upon closing
-    connect(dialog, &ComicArchiveDialog::archive, this, &ComicApplet::slotArchive);
-    dialog->show();
-}
-
-void ComicApplet::slotArchive(int archiveType, const QUrl &dest, const QString &fromIdentifier, const QString &toIdentifier)
-{
-    if (!mEngine) {
-        return;
-    }
-
-    mSavingDir->setDir(dest.path());
-
-    const QString id = mCurrent.id();
-    qDebug() << "Archiving:" << id << archiveType << dest << fromIdentifier << toIdentifier;
-    ComicArchiveJob *job = new ComicArchiveJob(dest, mEngine, static_cast<ComicArchiveJob::ArchiveType>(archiveType), mCurrent.type(), id, this);
-    job->setFromIdentifier(id + QLatin1Char(':') + fromIdentifier);
-    job->setToIdentifier(id + QLatin1Char(':') + toIdentifier);
-    if (job->isValid()) {
-        connect(job, &ComicArchiveJob::finished, this, &ComicApplet::slotArchiveFinished);
-        KIO::getJobTracker()->registerJob(job);
-        job->start();
-    } else {
-        qWarning() << "Archiving job is not valid.";
-        delete job;
-    }
-}
-
-void ComicApplet::slotArchiveFinished(KJob *job)
-{
-    if (job->error()) {
-        KNotification::event(KNotification::Warning, i18n("Archiving comic failed"), job->errorText(), QStringLiteral("dialog-warning"));
-    }
-}
-
 QList<QAction *> ComicApplet::contextualActions()
 {
     return mActions;
@@ -503,26 +473,22 @@ void ComicApplet::updateContextMenu()
         mActionGoFirst->setEnabled(false);
         mActionGoLast->setEnabled(false);
         mActionScaleContent->setEnabled(false);
-        if (mActionShop) {
-            mActionShop->setEnabled(false);
-        }
+        mActionWebsite->setEnabled(false);
+        mActionShop->setEnabled(false);
         mActionStorePosition->setEnabled(false);
         mActionGoJump->setEnabled(false);
         mActionSaveComicAs->setEnabled(false);
-        mActionCreateComicBook->setEnabled(false);
         mActionScaleContent->setChecked(false);
     } else {
         mActionGoFirst->setVisible(mCurrent.hasFirst());
         mActionGoFirst->setEnabled(mCurrent.hasPrev());
         mActionGoLast->setEnabled(true);
-        if (mActionShop) {
-            mActionShop->setEnabled(mCurrent.shopUrl().isValid());
-        }
+        mActionWebsite->setEnabled(true);
+        mActionShop->setEnabled(mCurrent.shopUrl().isValid());
         mActionScaleContent->setEnabled(true);
         mActionStorePosition->setEnabled(true);
         mActionGoJump->setEnabled(true);
         mActionSaveComicAs->setEnabled(true);
-        mActionCreateComicBook->setEnabled(true);
     }
 }
 
