@@ -9,7 +9,9 @@
 
 #include <KRunner/AbstractRunner>
 
-class CharacterRunner : public Plasma::AbstractRunner
+using namespace Plasma;
+
+class CharacterRunner : public AbstractRunner
 {
     Q_OBJECT
 
@@ -18,8 +20,8 @@ public:
     ~CharacterRunner() override;
 
     void reloadConfiguration() override;
-    void match(Plasma::RunnerContext &context) override;
-    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
+    void match(RunnerContext &context) override;
+    void run(const RunnerContext &context, const QueryMatch &match) override;
 
 private:
     // config-variables
