@@ -7,7 +7,11 @@
 
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KNotifications/KNotification>
+#include <QClipboard>
 #include <QEventLoop>
+#include <QGuiApplication>
+#include <QIcon>
 #include <QMutex>
 #include <QMutexLocker>
 #include <QStringList>
@@ -99,13 +103,23 @@ void DictionaryRunner::match(RunnerContext &context)
         match.setMultiLine(true);
         match.setText(lastPartOfSpeech + QLatin1String(": ") + reMatch.captured(2));
         match.setRelevance(1 - (static_cast<double>(++item) / static_cast<double>(lines.length())));
-        match.setType(QueryMatch::InformationalMatch);
+        match.setType(QueryMatch::HelperMatch);
         match.setIconName(QStringLiteral("accessories-dictionary"));
         matches.append(match);
     }
     context.addMatches(matches);
 }
 
+void DictionaryRunner::run(const RunnerContext &context, const QueryMatch &match)
+{
+    QString query = context.query();
+    if (query.startsWith(m_triggerWord, Qt::CaseInsensitive)) {
+        query.remove(0, m_triggerWord.length());
+    }
+    QGuiApplication::clipboard()->setText(query + QLatin1Char(' ') + match.text());
+    KNotification::event(KNotification::Notification, name(), i18n("Definition for \"%1\" has been copied to clipboard", query), icon().name());
+}
+
 K_PLUGIN_CLASS_WITH_JSON(DictionaryRunner, "plasma-runner-dictionary.json")
 
 #include "dictionaryrunner.moc"
