@@ -13,10 +13,12 @@
 #include <QMutex>
 #include <QSharedPointer>
 
+using namespace Plasma;
+
 /**
  * This checks the spelling of query
  */
-class SpellCheckRunner : public Plasma::AbstractRunner
+class SpellCheckRunner : public AbstractRunner
 {
     Q_OBJECT
 
@@ -24,14 +26,14 @@ public:
     SpellCheckRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~SpellCheckRunner() override;
 
-    void match(Plasma::RunnerContext &context) override;
-    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;
+    void match(RunnerContext &context) override;
+    void run(const RunnerContext &context, const QueryMatch &action) override;
 
     void reloadConfiguration() override;
 
 protected Q_SLOTS:
     void init() override;
-    QMimeData *mimeDataForMatch(const Plasma::QueryMatch &match) override;
+    QMimeData *mimeDataForMatch(const QueryMatch &match) override;
 
     void loadData();
     void destroydata();
@@ -40,10 +42,13 @@ private:
     QString findLang(const QStringList &terms);
 
     QString m_triggerWord;
+    QStringList m_availableLangCodes; // en_US, ru_RU, ...
     QMap<QString, QString> m_languages; // key=language name, value=language code
     bool m_requireTriggerWord;
     QMap<QString, QSharedPointer<Sonnet::Speller>> m_spellers; // spellers
     QMutex m_spellLock; // Lock held when constructing a new speller
+
+    friend class SpellCheckRunnerTest;
 };
 
 #endif
